package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````(`MP`!`````!I```````!``````````'@#`0``
M`````````$``.``)`$``'``;``8````$````0`````````!``$```````$``
M0```````^`$```````#X`0````````@``````````P````0````X`@``````
M`#@"0```````.`)````````;`````````!L``````````0`````````!````
M!0````````````````!``````````$```````*B4````````J)0`````````
M``$```````$````&````N/T```````"X_4$``````+C]00``````4`0`````
M``"8!````````````0```````@````8```#0_0```````-#]00``````T/U!
M``````#P`0```````/`!````````"``````````$````!````%0"````````
M5`)```````!4`D```````$0`````````1``````````$`````````%#E=&0$
M````,(T````````PC4```````#"-0```````#`$````````,`0````````0`
M````````4>5T9`8`````````````````````````````````````````````
M````````````$`````````!2Y71D!````+C]````````N/U!``````"X_4$`
M`````$@"````````2`(````````!`````````"]L:6(O;&0M;&EN=7@M86%R
M8V@V-"YS;RXQ```$````%`````,```!'3E4`NW_,3\LA#YMA#'B_XZ3_7`:F
M%OD$````$`````$```!'3E4```````,````'``````````P````]`````0``
M``8```!2"X``P0%`"CT````^````/P```$````!!`````````$(```!#````
M`````$0``````````````"%B9`<Y\HL<A_F<@0N*$%?%N9Q`I]VC:WOP2FO)
MU;)Q````````````````````````````````*`$``!(`````````````````
M````````S0$``!(`````````````````````````@````!(`````````````
M````````````L````!(`````````````````````````G`$``!(`````````
M````````````````W`$``!(``````````````````````````0```"``````
M````````````````````$@(``!(`````````````````````````"P(``!(`
M````````````````````````XP$``!(`````````````````````````IP``
M`!(`````````````````````````4P```!(`````````````````````````
MBP(``!(`````````````````````````NP```!(`````````````````````
M````&P(``!(`````````````````````````EP$``!(`````````````````
M````````Q0$``!(`````````````````````````I`$``!(`````````````
M````````````$````"``````````````````````````_@$``!(`````````
M````````````````"`$``!(`````````````````````````+````"``````
M````````````````````M0$``!(`````````````````````````L`(``!(`
M````````````````````````0`(``!(`````````````````````````A`(`
M`!(`````````````````````````J@(``!(`````````````````````````
M>`$``!(`````````````````````````]0```!8`````````````````````
M````\P$``!(`````````````````````````5`$``!(`````````````````
M````````V````!(`````````````````````````?0(``!(`````````````
M````````````F0(``!(`````````````````````````P@(``!(`````````
M````````````````^0$``!(`````````````````````````,0(``!(`````
M````````````````````R0```!(`````````````````````````A@$``!(`
M````````````````````````YP```!(`````````````````````````/@$`
M`!(`````````````````````````8P```!(`````````````````````````
M/P(``!(`````````````````````````D@(``!(`````````````````````
M````=0(``!(`````````````````````````K@$``!(`````````````````
M````````$P$``!(`````````````````````````9P(``!(`````````````
M````````````,@$``!(`````````````````````````!0(``!(`````````
M````````````````8`(``!(`````````````````````````+0$``!(`````
M````````````````````C````!(`````````````````````````10$``!(`
M````````````````````````U`$``!(`````````````````````````1P(`
M`!(`````````````````````````O@$``!(`````````````````````````
M[`$``!(`````````````````````````(P(``!(`````````````````````
M````;@(``!(`````````````````````````U`(``!$`%`#(_4$```````@`
M````````60(``!$`&0`0`D(```````@`````````;P```!(`````%D``````
M````````````1@```!$`&0`8`D(```````$`````````N`(``!$`&0`@`D(`
M``````@`````````N@(``"$`&0`@`D(```````@`````````EP```!(```#P
M%4``````````````````90$``!(```"@%$```````````````````%]?9VUO
M;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-7W)E
M9VES=&5R5$U#;&]N951A8FQE`%!,7V1O7W5N9'5M<`!097)L7V=V7V9E=&-H
M<'8`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?;&]C:P!097)L7V=E=%]S=@!0
M97)L7VYE=UA3`&)O;W1?1'EN84QO861E<@!P97)L7W)U;@!P97)L7W!A<G-E
M`%!E<FQ?<W9?<V5T<'8`4&5R;%]S=E]S971P=FX`<&5R;%]C;VYS=')U8W0`
M<&5R;%]D97-T<G5C=`!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO8P!0
M97)L7V-R;V%K7VYO8V]N=&5X=`!P97)L7V9R964`4&5R;%]S869E<WES;6%L
M;&]C`%!E<FQ?<WES7VEN:70S`%!E<FQ?;F5W6%-?9FQA9W,`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?<WES7W1E<FT`7U]S=&%C:U]C:&M?9F%I;`!E>&ET
M`&QS965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R
M<F-H<@!U;FQI;FL`;65M;6]V90!S=')T;VL`9V5T<'=U:60`<W1R;&5N`')M
M9&ER`')E860`<W1R<W1R`&UK9&ER`&=E='!I9`!R96%D;&EN:P!R96%L;&]C
M`%]?<W!R:6YT9E]C:&L`7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S
M=&%R=%]M86EN`'-T9&5R<@!M96UC:'(`<W1R8VAR`&UE;7-E=`!O<&5N9&ER
M`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N
M`&%B;W)T`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?
M<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XS-@!L:6)C+G-O+C8`;&0M
M;&EN=7@M86%R8V@V-"YS;RXQ`$=,24)#7S(N,3<`1TQ)0D-?,BXS-`!'3$E"
M0U\R+C,S``````$``@`!``$``@`"``$``@`"``(``0`!``(``0`"``(``@`"
M``$``@`!``$``@`"``0``@`"``$``0`"``$``0`"``(``@`"``(``0`"``$`
M`@`!``0``@`"``(``0`"``$``@`"``(``0`!``(`!0`"``(``@`"``,``@`!
M``$``@`"``$``0`````````!``$```,``!`````@````EY&6!@```P`6`P``
M``````$``P#V`@``$`````````"TD98&```%`"$#```0````LY&6!@``!``L
M`P``$````)>1E@8```(`%@,```````#(_T$```````$$```'````````````
M``#0_T$```````$$```3``````````````#8_T$```````$$```6````````
M``````#@_T$```````8$```=``````````````#(_4$````````$```]````
M```````````0`D(````````$```^```````````````8`D(````````$``!`
M```````````````@`D(````````$``!!`````````````````$(```````($
M```!```````````````(`$(```````($```"```````````````0`$(`````
M``($```#```````````````8`$(```````($```$```````````````@`$(`
M``````($```%```````````````H`$(```````($```&```````````````P
M`$(```````($``!$```````````````X`$(```````($```'````````````
M``!``$(```````($```(``````````````!(`$(```````($```)````````
M``````!0`$(```````($```*``````````````!8`$(```````($```+````
M``````````!@`$(```````($```,``````````````!H`$(```````($```-
M``````````````!P`$(```````($```.``````````````!X`$(```````($
M```/``````````````"``$(```````($```0``````````````"(`$(`````
M``($```1``````````````"0`$(```````($```2``````````````"8`$(`
M``````($```4``````````````"@`$(```````($```5``````````````"H
M`$(```````($```7``````````````"P`$(```````($```8````````````
M``"X`$(```````($```9``````````````#``$(```````($```:````````
M``````#(`$(```````($```;``````````````#0`$(```````($```<````
M``````````#8`$(```````($``!#``````````````#@`$(```````($```_
M``````````````#H`$(```````($```>``````````````#P`$(```````($
M```?``````````````#X`$(```````($```@`````````````````4(`````
M``($```A```````````````(`4(```````($```B```````````````0`4(`
M``````($```C```````````````8`4(```````($```D```````````````@
M`4(```````($```E```````````````H`4(```````($```F````````````
M```P`4(```````($```G```````````````X`4(```````($```H````````
M``````!``4(```````($```I``````````````!(`4(```````($```J````
M``````````!0`4(```````($```K``````````````!8`4(```````($```L
M``````````````!@`4(```````($```M``````````````!H`4(```````($
M```N``````````````!P`4(```````($```O``````````````!X`4(`````
M``($```P``````````````"``4(```````($```Q``````````````"(`4(`
M``````($```R``````````````"0`4(```````($```S``````````````"8
M`4(```````($```T``````````````"@`4(```````($```U````````````
M``"H`4(```````($```V``````````````"P`4(```````($```W````````
M``````"X`4(```````($```X``````````````#``4(```````($```Y````
M``````````#(`4(```````($```Z``````````````#0`4(```````($```[
M``````````````#8`4(```````($```\```````````````?(`/5_7N_J?T#
M`)&.`0"4_7O!J,`#7]8``````````/![OZGP``#0$?Y'^1#B/Y$@`A_6'R`#
MU1\@`]4?(`/5\```\!$"0/D0`@"1(`(?UO```/`1!D#Y$"(`D2`"'];P``#P
M$0I`^1!"`)$@`A_6\```\!$.0/D08@"1(`(?UO```/`1$D#Y$((`D2`"'];P
M``#P$19`^1"B`)$@`A_6\```\!$:0/D0P@"1(`(?UO```/`1'D#Y$.(`D2`"
M'];P``#P$2)`^1`"`9$@`A_6\```\!$F0/D0(@&1(`(?UO```/`1*D#Y$$(!
MD2`"'];P``#P$2Y`^1!B`9$@`A_6\```\!$R0/D0@@&1(`(?UO```/`1-D#Y
M$*(!D2`"'];P``#P$3I`^1#"`9$@`A_6\```\!$^0/D0X@&1(`(?UO```/`1
M0D#Y$`("D2`"'];P``#P$49`^1`B`I$@`A_6\```\!%*0/D00@*1(`(?UO``
M`/`13D#Y$&("D2`"'];P``#P$5)`^1""`I$@`A_6\```\!%60/D0H@*1(`(?
MUO```/`16D#Y$,("D2`"'];P``#P$5Y`^1#B`I$@`A_6\```\!%B0/D0`@.1
M(`(?UO```/`19D#Y$"(#D2`"'];P``#P$6I`^1!"`Y$@`A_6\```\!%N0/D0
M8@.1(`(?UO```/`1<D#Y$((#D2`"'];P``#P$79`^1"B`Y$@`A_6\```\!%Z
M0/D0P@.1(`(?UO```/`1?D#Y$.(#D2`"'];P``#P$8)`^1`"!)$@`A_6\```
M\!&&0/D0(@21(`(?UO```/`1BD#Y$$($D2`"'];P``#P$8Y`^1!B!)$@`A_6
M\```\!&20/D0@@21(`(?UO```/`1ED#Y$*($D2`"'];P``#P$9I`^1#"!)$@
M`A_6\```\!&>0/D0X@21(`(?UO```/`1HD#Y$`(%D2`"'];P``#P$:9`^1`B
M!9$@`A_6\```\!&J0/D00@61(`(?UO```/`1KD#Y$&(%D2`"'];P``#P$;)`
M^1""!9$@`A_6\```\!&V0/D0H@61(`(?UO```/`1ND#Y$,(%D2`"'];P``#P
M$;Y`^1#B!9$@`A_6\```\!'"0/D0`@:1(`(?UO```/`1QD#Y$"(&D2`"'];P
M``#P$<I`^1!"!I$@`A_6\```\!'.0/D08@:1(`(?UO```/`1TD#Y$((&D2`"
M'];P``#P$=9`^1"B!I$@`A_6\```\!':0/D0P@:1(`(?UO```/`1WD#Y$.(&
MD2`"'];P``#P$>)`^1`"!Y$@`A_6\```\!'F0/D0(@>1(`(?UO```/`1ZD#Y
M$$('D2`"'];P``#P$>Y`^1!B!Y$@`A_6_7N[J>,``-!C(#>1_0,`D?-3`:GB
MAP*IXJ,`D>'#`)'@/P"YX/,`D60`0/GD)P#Y!`"`TM?__Y<"``"00H`2D>$#
M`JH```"0```8D8T,`)3@``#P`&!(.8`(`#3@``#0`/!'^?,``/!!T#O5<\((
MD2)H8/CT/T"Y02A2.8`2`!&4#@`1(00`,D$H$CD`?'V3K/__E^,#`*KF&T#Y
MX@``\.4_0+D!``#P0@!!^2$@.)'$`$#Y````\`!`.)%D!`"I8P8`^6(``:F_
M!`!Q;0@`5"$`@-(?(`/5(`P`$<1X8?@A!`"19-@@^+\``6ML__]4I0P`$6`.
M0/E_V"7XX@,4*@$``+`$`(#2(0`)D=G^_Y?T`P`J(`0`-&`.0/EE__^7````
M\.$3`9$`0"Z1>0``E,`#`+1@#D#YPO[_ERG__Y?@``#0XB=`^0'D1OE"``'K
M`0"`TJ$$`%3@`Q0J\U-!J?U[Q:C``U_6\P``\'/"")$$__^78`X`^4`#`+0M
M__^7X```T`#P1_E!T#O5(FA@^%_<*#FW__\78`Y`^=7^_Y?T`P`JW?__%V`*
M0/E@``"T"`<`E.#__Q?A$P&1````\`!@+)%3``"48`H`^4#[_[0`!P"4V/__
M%X4`@%+&__\7(`"`4M?^_Y<N__^7'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5
M'0"`TAX`@-+E`P"JX0-`^>(C`)'F`P"1````D`#0*)$#`(#2!`"`TF'__Y?H
M_O^7'R`#U7+__Q<?(`/5P`-?UN```-``Y$?Y0```M)C^_Q?``U_6'R`#U1\@
M`]7@``#P`"`(D>$``/`A(`B1/P``Z\```%3A``#0(>A'^6$``+3P`P&J``(?
MUL`#7];@``#P`"`(D>$``/`A(`B1(0``RR+\?]-!#(&+(?Q!D\$``+3B``#0
M0NQ'^6(``+3P`P*J``(?UL`#7]8?(`/5_7N^J?T#`)'S"P#Y\P``\&"B2#F`
M```UWO__ER``@%)@H@@Y\PM`^?U[PJC``U_6Y/__%Q\@`]4?(`/5'R`#U?U[
MO*G]`P"1\U,!J6`&`+3W8P.I]P,`JN```/`8$$'Y&`8`M/5;`JGV`P&J%0"`
M4N`"0#D?]`!Q!!A`>J$"`%03`T#YLP$`M+5^0)/T`QBJX@,5JN$#%ZK@`Q.J
MC?[_EX```#5@:G4X'_0`<0`"`%23CD#X\_[_M?5;0JGW8T.IX`,3JO-30:G]
M>\2HP`-?UO4#%ZJ@'D`X'_0`<0080'JA__]4M0(72^;__Q>``AC+M08`D7,"
M%8L`_$.3P`(`N>`#$ZKS4T&I]5M"J?=C0ZG]>\2HP`-?UA,`@-+I__\7]V-#
MJ1,`@-+F__\7'R`#U?U[M:GA``#0(2`WD?T#`)'S"P#Y\P,`JB(`0/GB5P#Y
M`@"`TN&C`)&N_O^7``(`->$[0+D"`)12(0P4$C\00'$D$$)Z@`$`5.$``-#C
M5T#Y(N1&^6,``NL"`(#2@0$`5/,+0/G]>\NHP`-?U@``@%+V__\7X`,3JD$`
M@%)1_O^7'P``<>`7GQKP__\7A?[_E_U[M*GA``#0(2`WD?T#`)$B`$#YXE\`
M^0(`@-+```"T\U,!J?,#`*H!`$`Y00$`-?-30:G@``#0XE]`^0'D1OE"``'K
M`0"`TH$(`%3]>\RHP`-?UO5;`JF&_O^7]`,`JD`&`+3@`Q2J&O[_EV`%`+0!
M3$`Y%4P`D3^X`'%A``!4H09`.0'__S0`3$`Y'[@`<2`%`%3@`Q.JJO[_E_8#
M`*K@`Q6JI_[_E\`"``L`"``1`'Q`DU_^_Y?E`Q6JY`,3J@,``/!CH"J1`@"`
MDO4#`*HA`(!2G_[_E^`#%:KAXP"1$/[_EQ\$`#&@``!4X$M`N0`,%!(?$$!Q
MH`(`5.`#%:JP_?^7X`,5JG;^_Y?@`Q2J\/W_E^#Z_[7@`Q2J^?W_E^`#$ZH7
M_O^7\U-!J?5;0JG!__\7H`9`.1^X`''!^O]4H`I`.0#Y_S33__\7X`,5JJS_
M_Y?L__\7\U,!J?5;`JDL_O^7_T,!T>$``-#_0T#1(2`WD>)#0)']>P"I_0,`
MD?-3`:GT`P`J\P,!D?5;`JD5`8#2-0"@\O<;`/GV``#P(P!`^4,D`/D#`(#2
M`0"`TD(`@%*/_?^7%P0`T>`#%^OA/D"2`#Q`DB!$@-KW`@#KA`4`5!\@`]7A
M`Q>J`@"`4N`#%"J#_?^7X@,5JN$#$ZK@`Q0J^_W_EP!\0),?'`#QJ0,`5`$@
M`-%A`@&K0@,`5,#"!Y$$```4(00`T3\`$^NC`@!4`@!`^2,`0/E_``+K0?__
M5"$`$\L@`!>+XT-`D>$``-!D)$#Y(N1&^80``NL"`(#2H0$`5/U[0*GS4T&I
M]5M"J?<;0/G_0P&1_T-`D<`#7];W0D#1_T)`L>'Z_U0``("2[O__%^+]_Y<?
M(`/5#`B"TO]C+,OC``#08R`WD>+_@=+]>P"I_0,`D?-3`:GS`P"J]`,!JF``
M0/G@'PCY``"`TN'C`)$```#P`,`JD5C]_Y<?``!Q#0,`5`0$`%'B`P`JX.,`
MD0#(9#A``@`T]1,`^55\0)/@XP"1X@,5JN$%@%+S_?^7P`,`M.```-``\$?Y
M1-`[U>,#%:KBXP"1X0,3JH!H8/BV_?^7]1-`^0D``!2D`@`UX```T`#P1_E#
MT#O5X@,4JN$#$ZI@:&#X4/W_E^```-#B'TCY`>1&^4(``>L!`(#280$`5/U[
M0*D,"(+2\U-!J?]C+(O``U_6]1-`^>W__Q?B`P0J]1,`^=G__Q?U$P#YGOW_
MEQ\@`]7]>[JI_0,`D?-3`:GT`P&JX0``L/5;`JDA(#>1\P,`JO=C`ZD@`$#Y
MX"\`^0``@-*``D`Y'_0`<906E)K@`Q2JV/W_E_8#`*KA4P&1X`,3JJ3^_Y?`
M!P"T]0,`JM']_Y??`@#KB08`5/=7@+GX``#0]_)]TV`"0#D?]`!Q!!A`>D`+
M`%3D`Q.J@QQ`.'_T`'%D&$!ZH?__5(0`$\N$?$"3%1-!^<`*`)$```2+>?W_
MEZ!J-_B@`@"T`1-!^>`#$ZHC:'?X`11`.&$``#D_]`!Q)!A`>L```%0"%$`X
M8AP`.%_T`'%$&$!Z@?__5*$'@%(``(#2810`.()J8#AB:"`X``0`D:+__S7@
M``"PXB]`^0'D1OE"``'K`0"`T@$'`%3S4T&I]5M"J?=C0ZG]>\:HP`-?U@$`
M@-*":F$XHFHA."$$`)&B__\U\/__%_@``-#Y:P2I&A-!^4`#0/F@!`"TX`,:
MJA4`@%(!C$#XX@,5*K4&`!&A__^U0`P`$0!\?9/A``#0(C!"N0("`#4B`(!2
M(C`"N3_]_Y?Y`P"J0`,`M+=^?9/A`QJJX@,7JG']_Y<9$P'YH`8`$?57`+D_
MVR#X^6M$J:S__Q?A`P"JX`,:JLS\_Y<`$P'Y^0,`JD`!`+2W?GV3]/__%P0`
M@-*M__\7``*`TA4`@%+B__\7^6L$J1S]_Y?Y:T2IP/__%Q\@`]7]>[ZI(P``
MT.+___#]`P"1\U,!J530.]7S``"P<_)'^6,`,I%"P!>1`0``T"$`*Y&`:G/X
M0_W_EX!J<_@$``#0\U-!J80`.)']>\*HXP,$J@(``+`!``#00A`/D2&`*Y$%
M`(!2W_S_%Q\@`]4?(`/5X```L`#P1_E$T#O5(P``T.+___!C`#*10L`7D0$`
M`-`A`"N1@&A@^"K]_Q<?(`/5#`B$TO]C+,O@``"P`"`WD?U[`*G]`P"1\U,!
MJ0$`0/GA'Q#Y`0"`TG+\_Y?D`P`J!0``T`,``-"EX"N18P`LD2(`@M(A`(!2
MX*,`D2W]_Y<"!H+2X*,`D>%C(HL"`(+28/S_ET`#^#?S`P"J``0`$0!\0)/;
M_/^7]`,`JH`"`+1S?D"3`0:"TN(#$ZKA8R&+:/S_EY]J,SC@``"PXA]0^0'D
M1OE"``'K`0"`TN$``%3]>T"IX`,4JO-30:D,"(32_V,LB\`#7]:^_/^7%`"`
MTO+__Q?+__\7'R`#U1\@`]4,'(+2_V,LR^(``+!"(#>1_7L`J?T#`)'S4P&I
M\P,!JN%3`9'U6P*I]0,`JD``0/G@;PCY``"`T@```-``8"R1Q/W_E_0#`*KA
M!8!2X`,5JLC\_Y=``@"TX0,5J@```-``H"R1`___E^`#%:KA``"PXV](^2+D
M1OEC``+K`@"`T@$-`%3]>T"I#!R"TO-30:GU6T*I_V,LB\`#7];@`Q.J%@``
MT*O\_Y?6XBR1X0,6J@C\_Y?S`P"J`/W_M/=C`ZD8``#0%P``T!@#+9'W(BV1
M^2,`^1\@`]5@`D`YH`8`-+0``+3A`Q.JX`,4JI'\_Y<`!0`TX`,3JL;\_Y<"
M!`#1^0,`JF("`HM_`@+KHP``5`H``!1?]!\X?P("ZX```%1``$`Y'[P`<6#_
M_U3@`Q.JN/S_E_D#`*K@`Q6JM?S_EP``&8L`!`"1'_P_\<@"`%3D`Q.JY@,5
MJN4#&*KC`Q>J`@""TB$`@%+@8P.1K?S_E^%C`9'@8P.1'OS_EZ```#7@:T"Y
M``P4$A\@0'&``@!4X0,6J@``@-+.^_^7\P,`JL#Y_[7W8T.I^2-`^:O__Q<4
M`P"T@`)`.1^X`'&@``!4$P``T#D`@-)S0BR1V___%X`&0#G@_?\T^O__%^!C
M`Y$A`(!2!_S_ET#]_S7A8P.1````T`"@+)&>_O^7X&,#D53\_Y?W8T.I^2-`
M^9C__Q<3``#0.0"`TG-"+)''__\7]V,#J?DC`/DN_/^7'R`#U?U[OJGA!8!2
M_0,`D?,+`/GS`P"JT_O_EQ\``/%@!H":\PM`^?U[PJ@^_/\7'R`#U0P(@M+_
M8RS+X0``L"$@-Y']>P"I_0,`D2(`0/GB'PCY`@"`TN`%`+3U$P#Y]0,`J@$`
M0#E!!0`T\U,!J5W\_Y<"!`"1\P,`JE\$0/%H!@!4].,`D>$#%:K@`Q2JI?O_
MEV`&`-&``@"+'P`4ZZ@``%0'```4'_0?.!\`%.N```!4`0!`.3^\`'%@__]4
MX`,4JN$%@%*G^_^70`0`M!\`%.N(`P!4X`,4JA+\_Y?A``"PXQ](^2+D1OEC
M``+K`@"`TF$$`%3]>T"I#`B"TO-30:GU$T#Y_V,LB\`#7];U$T#YX```L.(?
M2/D!Y$;Y0@`!ZP$`@-+A`@!4````T`!`+)']>T"I#`B"TO]C+(OY^_\7'P``
M.>3__Q<``(#2Y/__%^```+#B'TCY`>1&^4(``>L!`(#2P0``5/-30:D```#0
M]1-`^0!`+)'N__\7S?O_E_-3`:GU$P#YROO_EQ\@`]7]>[NIX```L``@-Y']
M`P"1\U,!J1,``-!S0BV1]5L"J?0``-#W8P.I`0!`^>$G`/D!`(#2X1,!D>`#
M$ZK5_/^7``(`M((20?GC1X"Y0`P#BP$$0/E!>"/XX?[_M!\@`]4!"$#Y`00`
M^0`@`)&A__^UX1,!D>`#$ZK&_/^70/[_M1,``-!S@BV1]```T.$3`9'@`Q.J
MO_S_EP`"`+2"$D'YXT>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5`0A`^0$$`/D`
M(`"1H?__M>$3`9'@`Q.JL/S_ET#^_[43``#0<Z(MD?0``-#A$P&1X`,3JJG\
M_Y<``@"T@A)!^>-'@+E`#`.+`01`^4%X(_CA_O^T'R`#U0$(0/D!!`#Y`"``
MD:'__[7A$P&1X`,3JIK\_Y=`_O^U$P``T'/B+9'T``#0X1,!D>`#$ZJ3_/^7
M``(`M((20?GC1X"Y0`P#BP$$0/E!>"/XX?[_M!\@`]4!"$#Y`00`^0`@`)&A
M__^UX1,!D>`#$ZJ$_/^70/[_M1,``-!S`BZ1]```T.$3`9'@`Q.J??S_EP`"
M`+2"$D'YXT>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5`0A`^0$$`/D`(`"1H?__
MM>$3`9'@`Q.J;OS_ET#^_[44``#0E$(ND?4``-#A$P&1X`,4JF?\_Y<``@"T
MHA)!^>-'@+E`#`.+`01`^4%X(_CA_O^T'R`#U0$(0/D!!`#Y`"``D:'__[7A
M$P&1X`,4JEC\_Y=`_O^U%```T)1B+)'U``#0X1,!D>`#%*I1_/^7``(`M*(2
M0?GC1X"Y0`P#BP$$0/E!>"/XX?[_M!\@`]4!"$#Y`00`^0`@`)&A__^UX1,!
MD>`#%*I"_/^70/[_M14``-"U@BZ1]@``T.$3`9'@`Q6J._S_EP`"`+3"$D'Y
MXT>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5`0A`^0$$`/D`(`"1H?__M>$3`9'@
M`Q6J+/S_ET#^_[46``#0UL(ND?<``-#A$P&1X`,6JB7\_Y<``@"TXA)!^>-'
M@+E`#`.+`01`^4%X(_CA_O^T'R`#U0$(0/D!!`#Y`"``D:'__[7A$P&1X`,6
MJA;\_Y=`_O^U%P``T/<"+Y'X``#0X1,!D>`#%ZH/_/^7``(`M`(30?GC1X"Y
M0`P#BP$$0/E!>"/XX?[_M!\@`]4!"$#Y`00`^0`@`)&A__^UX1,!D>`#%ZH`
M_/^70/[_M1<``-#WHBR1^```T.$3`9'@`Q>J^?O_EP`"`+0"$T'YXT>`N4`,
M`XL!!$#Y07@C^.'^_[0?(`/5`0A`^0$$`/D`(`"1H?__M>$3`9'@`Q>JZOO_
MET#^_[7A$P&1````T`!`+Y'E^_^7X0,`JF```+3@`Q:J*?W_E^$3`9$```#0
M`*`OD=W[_Y?A`P"J@```M````-```#"1(/W_E^$3`9$```#0`$`PD=3[_Y?A
M`P"J(`(`M.`#%*H8_?^7X```L.(G0/D!Y$;Y0@`!ZP$`@-)!`@!4]5M"J>`#
M$ZKS4T&I`0``T/=C0ZDAX#"1_7O%J`K]_Q?A$P&1````T`"`,)&^^_^7X0,`
MJJ#]_[3@`Q6J`OW_E^K__Q><^O^7_7N^J>```+``(#>1_0,`D0$`0/GA#P#Y
M`0"`T@```-#A4P"1`(`ND:W[_Y>@`0"T``!`.1_``'$$&$!ZX`>?&N$``+#C
M#T#Y(N1&^6,``NL"`(#2H0``5/U[PJC``U_6``"`4O?__Q>!^O^7_7N_J?T#
M`)%F^O^7#?K_ET```+0``$#Y_7O!J,`#7];]>[RIX0``L"$@-Y']`P"1\U,!
MJ10``-"4`C&1]5L"J?4#`*H@`$#YX!\`^0``@-+ATP"1X`,4JH;[_Y<@`@"T
M`0!`.?,#`*K!`0`TX0,5JACZ_Y?@`@"TX```L.(?0/D!Y$;Y0@`!ZP$`@-)!
M!0!4\U-!J?5;0JG]>\2HP`-?UN```+#B'T#Y`>1&^4(``>L!`(#2X0,5JN$#
M`%3U6T*IX`,4JO-30:G]>\2HL?S_%^`#%:J7^O^7]@,`JN`#$ZJ4^O^7P`(`
MBP`(`)%-^O^7(0"`4N8#$ZH"`("2\P,`JN0#%:H%``#0`P``T*7@+)%C("V1
MB_K_E^```+#B'T#Y`>1&^4(``>L!`(#2X0,3JF#\_U0S^O^7'R`#U1\@`]7_
M0P;1(0``T"$`,I'B``"P(Z``D4(@-Y']>P&I_4,`D2@D0:GS4P*I]`,`JB:<
M1:GU6P.I%0``T&$(0*U``$#YX,<`^0``@-(D$$#YM6(LD6`(P#W@`Q6J(S1`
M^>&S`9'H)P>IY$,`^>:?"*GC3P#YX0L%K>`S@#TN^_^7@```M`$`0#GS`P"J
MH2$`-?=C!*GY:P6I\_G_EYKY_Y>@#P"T%P!`^7</`+3@`Q>J4?K_EP#X?],`
M!`"1"OK_E_,#`*KD`D`Y]@,`JH0!`#08``#0&&,QD1\@`]7@`Q.JXP,8J@(`
M@)(A`(!21OK_EW,*`)'D'D`X)/__-0$``-#W@P*1(``PD0,``!3@CD#XH`$`
MM.&S`9$'^_^7\P,`JF#__[0!`$`Y(?__-#[[_Y?@_O\TX`,3JO_Y_Y?S`P"J
MH`$`M??#`9'S`D#Y4P$`M&`"0#G`"0`TX`,3JC+[_Y>@"``U\P9`^?<B`)$S
M__^U'R`#U>`#$ZH?^O^7]P,`JN`#%JH<^O^7^0(`"SD3$!$8``#0&`,MD3E_
M0)/@`QFJT?G_E^<#%JKD`Q.JY0,8J@8``-`#``#0QH`QD6.@,9$"`("2]P,`
MJB$`@%(.^O^7X`,7J@$X@%+G^?^7'P0`,:$``%2D^?^7!0!`N;]$`'%A%0!4
MX4,#D>`#%ZK"^?^7\P,`*J```#7@XT"Y``P4$A\00'%@!P!4X```T`(``-"#
M`D#YY`,7J@`(0?E"X#*1(0"`4ISY_Y<6`(#2X```D.+'0/D!Y$;Y0@`!ZP$`
M@-)!'`!4_7M!J>`#%JKS4T*I]5M#J?=C1*GY:T6I_T,&D<`#7];@`Q.J]R(`
MD:[Y_Y?S`P"J(/;_M+O__Q<3`(#2N?__%^!'0/GS(P*10`$`M!\@`]7ALP&1
MH_K_EV```+0!`$`Y@0$`-6`&0/ES(@"1(/__M:`!@-*'^?^7%P``L/,#`*KW
M0C&1]@,`JF0*@%)\__\7E/G_E_<#`*I@_O^TP?G_EP#X?],`!`"1</__%_;K
M0+E8^?^7WP(`:V'X_U3@XT"Y`"``$A\`!W'A]_]4X`,9JG#Y_Y<!``"P]@,`
MJB!`-)'ALP&1?_K_E^$#`*J@#0"T@`)`^:?\_Y?Z`P"J(`T`M.`#&JJG^?^7
M^0,`JA\,`''-`0!4`'Q`DP$``+``$`#1(6`TD4`#`(MF^?^7X```-3\3`''`
M$`!4.1<`44#+>3@?O`!Q0!``5!0``+"4@BZ1X;,!D>`#%*IB^O^7H```M```
M0#D?P`!Q!!A`>L$``%3@`QJJ`0"`4H;Y_Y?Y`P`J0`D`->`#%*H!``"P(>`P
MD9S[_Y<4``"PE`(XD1D``+`Y(S61O_C_E^8#`"KG`Q2JY0,8JN0#%ZK@`Q:J
M`P``L`(`@))CX#21(0"`4GGY_Y<1```4$_G_EP``0+D?1`!Q00(`5*_X_Y?T
M`P#Y<P8`$>8#`"KG`Q,JY0,8JN0#%ZKC`QFJX`,6J@(`@)(A`(!2:/G_E^`#
M%JH!.(!20?G_EQ\$`#&`_?]4X`,7JD7Y_Y?A`Q:JX`,5JG+[_Y?@`Q:JE/[_
MEVG__Q?@``"PY`,7JH,"0/D"``"P``A!^4+@,9$A`(!2^_C_EU___Q>)_O^7
MX```D.+'0/D!Y$;Y0@`!ZP$`@-(A"`!4_7M!J>`#$ZKS4T*I]5M#J?]#!I$1
M^?\7F@)`^9?__Q?'^O^7^@,`JJ#V_[<!*`#1`@"`4N`#&2ID^/^7X4,%D>`#
M&2K"`(#2W/C_E^%30;D`8(A2(&BH<C\``&L!]?]4X:M">0"IB%(_``!K@?3_
M5$'+`-'@`QDJ`@"`4E/X_Y?A8P61X`,9*@(%@-++^/^7YF,%D>4#&*KD`Q>J
MX`,6J@<``+`#``"PYP`XD6.@-)$"`("2(0"`4O\#!CD;^?^7N/__%Y0&0/G4
M[_^TX`,4JA+Y_Y<?#`#Q2>__5``0`-$!``"P@`(`BR&`-)'3^/^7'P``<5H3
ME)IR__\7N_C_E_=C!*GY:P6IN/C_E_U[O*G@``"0`"`WD?T#`)'S4P&I5-`[
MU?,``)!S\D?Y]5L"J0$`0/GA'P#Y`0"`T@```+"5:G/XX=,`D0``+I&BPD(Y
MHL8".<'Y_Y>```"T`0!`.3_$`''`"@!4V/S_EY5J<_C@`Q6J`0``L&,`@%(A
M@#61(@"`4C'X_Y?U`P"J8`$`M*$*0/D"``"P@&IS^$*@-9$A`$#Y,?C_EZ`*
M0/D!`$#Y(`Q`N:`)L#>`:G/X`0``L&,`@%(AP#61(@"`4A_X_Y?V`P"J8`$`
MM.'3`)$```"P`*`LD9WY_Y?B`P"JX`8`M,$*0/F`:G/X(0!`^1OX_Y?U``"P
MM<((D99J<_@B`(!2`0``L"'@-9'@`Q:JX_?_EP(``+#A`P"J0D`VD>`#%JH.
M^/^7@FIS^.'3`)$```"P`&`LD5_$`CF$^?^7H`H`^?,#`*I``@"T`3B`4N`#
M$ZJ.^/^7`00`$3\$`'$$B%%Z000`5.```)#B'T#Y`>1&^4(``>L!`(#280,`
M5/-30:GU6T*I_7O$J,`#7]:@!D#Y(O[_EZ`*`/GS`P"J8/W_M0```+``8#:1
M;/C_EP`$0#F`]?\TJ?__%_4``+"UP@B1P`I`^:$&0/D``$#Y(0!`^6+Z_Y?)
M__\7@&IS^$OX_Y>R__\7/?C_EZ$&0/GC`P`JX@,3J@```+```#>1(0!`^5;X
M_Y<?(`/5_7N]J>$``)`A(#>1_0,`D?-3`:GS`P"J(@!`^>(7`/D"`(#2"_S_
ME_0#`*KA!8!2U/?_EQ\``/&`!H":0?C_E_0#`*KADP"1````L`"`+I$\^?^7
M(`$`M```0#D?P`!Q!!A`>N`'GQI_`@#QX0>?&C\``&I!`0!4X```D.(70/D!
MY$;Y0@`!ZP$`@-+!`@!4\U-!J?U[PZC``U_68`)`.<#^_S0!``"PX`,4JB&`
M,9&"`(#2Q_?_EP#^_S7@``"0XA=`^0'D1OE"``'K`0"`TJ$``%3@`Q.J\U-!
MJ?U[PZAX^?\7^_?_EQ\@`]4?(`/5_X,*T>$``)!1Y`!O(B`WD?#E`&\!X`"1
M_7L`J0/@`9']`P"1A^0`;T0`0/GD3P'Y!`"`TN)#`)$C`$!M(@3!/&,X@`Y!
M!&!O0`18;V,(("Y"!$AO)E183P`<,4YDI"`O(51(3\,<,$X`'*).(1PG3@`<
MHTX%'*%.1(R?3'\``>O!_?]4\!]!K>+C"9'F#T*MX>,!D>430ZWA(\`]\>4`
M;R*`V3PA0`"1(`#?/``<(FX`'"-N`!PP;O`<IT[''*9.9ARC3@)404\`!&%O
MHQRE3H4<I$XD'*%.0!R@3@$<,4XA@(`\/P`"Z\']_U0'*$"I)#./T@@D0:E$
M4*ORY3]!J2-TG=+B_%O3[/Q"TT(4!ZJ,>0>J(0$(RB/;K?(A``J*(0`)RJ4`
M!(LB0"*+0?U"TPL00/DA>`JJ+7Q`DD(`!8NE`0C*0@`+"^9#0JFE``>*I0`(
MRN\!!(M._%O3I0`)B\X5`JHA``S*I0`/BR$``HJE``X+3_Q"TR$`#<KB>0*J
MQ@`$BZ[\6],A``B+SA4%JB$`!HN&`0+*(0`."XQ]0)+&``6*KOQ"T\8`#,H0
M`@2+Q@`-BR_\6]/->06J[Q4!JNX;0/E%``W*Q@`0BT)\0)+&``\+I0`!BJ4`
M`LHP_$+3S@$$BZ4`#(O/_%O3#'H!JN\5!JJE``Z+I0`/"Z$!#,K/_$+3(0`&
MBN9Y!JJM?4"2[K]#J2$`#<HA``*+L/Q"T\(!!(NN_%O3(0`"BX(!!LI"``6*
MC'U`DLX5!:I"``S*+@`."P5Z!:KA`02+0@`-BT(``8O!``7*T'Q`DB$`#HHA
M`!#*S?U;TR$`#(NM%0ZJ[[-$J4T`#0O&_4+3SG@.JJ9\0)+B`02+K_U;TR$`
M`HNB``[*[Q4-JD(`#8HO``\+I?U"TT(`!LJ!`02+I7@-JD(`$(M"``&+[/U;
MT\$!!<KP_4+3C!4/JB$`#XH/>@^J3``,"^W#1:G.?4"2(0`.RB$`!HN&_5O3
MQA0,JJ(!!(L0`@2+(0`"BZ(`#\HM``8+I7Q`DD(`#(J&_4+30@`%RL9X#*JA
M_5O30@`.BT(`$(LL%`VJL/U"T^$!!LHA``V*#7H-JN[#1JE,``P+[WU`DB$`
M#\HA``6+A?U;TZ44#*K"`02+$`($BR$``HO"``W*+@`%"\9\0))"``R*A?U"
MTT(`!LJE>`RJP?U;TT(`#XM"`!"++!0.JM#]0M.A`07*(0`.B@YZ#JKOPT>I
M3``,"ZU]0)(A``W*(0`&BX;]6]/&%`RJX@$$BQ`"!(LA``*+H@`.RB\`!@NE
M?$"20@`,BH;]0M-"``7*QG@,JN']6]-"``V+0@`0BRP4#ZKP_4+3P0$&RB$`
M#XH/>@^J[<-(J4P`#`O.?4"2(0`.RB$`!8N%_5O3I10,JJ(!!(L0`@2+(0`"
MB\(`#\HM``4+A?U"TZ5X#*I"``R*H?U;T\9\0)(L%`VJX0$%RB$`#8KO?4"2
M0@`&RB$`#\I"``Z+(0`&B^Z;2:E"`!"+3``,"[#]0M,->@VJD/U"T\(!!(N.
M_5O3(0`"B\X5#*JB``W*+@`."Z5\0))"``R*0@`%R@QZ#*K!``2+0@`/B\;]
M6]-"``&+[U=`^:$!#,K&%`ZJK7U`DM(``@LA``Z*(0`-RN0!!(LA``6+T/U"
MTT7^6],.>@ZJ[UM`^2$`!(NE%!*J1D`FB[```0N$`0[*A``&2N(!`XN$``V+
M!OY;TTW^0M.$``*+XE]`^;)Y$JK&%!"J)4`EB\\`!`O!`1+*)0`%2D$``XNB
M0"R+#/Y"T^7]6].->1"J0@`!BZ44#ZKA8T#YL0`""X9`)HM$`@W*A``&2NS]
M0M,F``.+@4`NBR3^6]./>0^J(0`&BX04$:KF9T#YD``!"T5`)8NB`0_*10`%
M2B[^0M/1>1&JK$`RB\(``XL%_EO3YFM`^8(!`HNE%!"J)$`DB^$!$<JN``(+
M)``$2@S^0M/!``.+AD`MBY!Y$*K!``&+YF]`^<3]6]-%0"6+A!0.JB("$,J-
M``$+0@`%2L8``XM"0"^+S/U"TXYY#JI"``:+YG-`^:7]6].E%`VJ)$`DBP$"
M#LJO``(+(0`$2JS]0M.->0VJQ@`#BR%`,8OD_5O3(0`&BT5`)8OF=T#YP@$-
MRH04#ZI%``5*D0`!"ZQ`,(OP_4+3P@`#B^9[0/D/>@^J)?Y;TR1`)(NA`0_*
M@@$"BZ44$:HD``1*L``""\$``XLL_D+3AD`NBXQY$:K!``&+YG]`^45`)8L$
M_EO3X@$,RH04$*I"``5*C@`!"\8``XM"0"V+#?Y"T_&#0/E"``:+IGD0JB1`
M)(O%_5O3@0$&RJ44#JHA``1*K0`""S`"`XLA0"^+S_U"TR$`$(ON>0ZJ\(=`
M^:3]6].$%`VJ14`EB[']0M/"``[*CP`!"RUZ#:I%``5*`@(#B_"+0/DD0"2+
MP0$-RJQ`+(LD``1*Y?U;TZ44#ZJ&0":+\?U"TP$"`XO!``&+@@$"BR9Z#ZJL
M``(+14`EBZ(!!LI"``5*A/U;TT)`+HN$%`RJ\+M1J9']0M./``$++'H,JB1`
M)(O!``S*Y?U;TR$`!$KQ_4+3I10/JA`"`XLO>@^J0@`0BR%`+8OMQU*IL``"
M"\X!`XM%0"6+!/Y;TR$`#HN$%!"J@@$/RHX``0M"``5*0D`FBZ4!`XL-_D+3
M10`%B\;]6].B>1"JQA0.JB1`)(OA`0+*S0`%"R0`!$HA`@.+A$`LB]']0M/P
MGT#YA``!BZS]6],A>@ZJC!4-JJ9`)HM%``'*C@$$"Z4`!DH0`@.+I4`OBZ_]
M0M/O>0VJI0`0B_"C0/G&_5O3QA0.JHQ`+(LD``_*S0`%"XP`#$K1_4+3!`(#
MBX)!(HNP_5O30@`$BR1Z#JJF0":+[*=`^1`6#:KE`03*0@`0"Z4`!DJN_4+3
MH4`AB\5Y#:J&`0.+3OQ"TXP`!:I#_%O38Q0"JHP!`HK">0*J(0`&B^T[5:DA
M``,+HP`$"H:;E]*,`0.J9N.Q\H-!+XLO_$+3K`$&BRW\6].M%0&J8P`,BZP`
M`JIC``T+C`$!BDT`!0J,`0VJX7D!JLX!!HN$022+;?Q;TTP``:JM%0.JA``.
MBX0`#0N,`0.*+0`""F[\0M.,`0VJC?Q;TX5!)8O,>0.J[SM6J:,5!*HM``RJ
M[P$&B\X!!HNE``^+C_Q"TZ,``PNE`02*C0$!"J4`#:IM_%O3I4`BB^)Y!*JM
M%0.JA`$"JJ4`#HN$``.*I0`-"TT`#`J$``VJ;?Q"TX1`(8NA>0.J[S=7J:[\
M6]/.%06J0P`!JF,`!8KO`0:+K0$&BX0`#XNO_$+3A``."RX``@IC``ZJY7D%
MJF-`+(N._%O3SA4$JBP`!:IC``V+C`$$BNW#0/EC``X+K@`!"H_\0M.,`0ZJ
MY'D$JH)!(HMN_%O3K`$&B\X5`ZKMQT#Y0@`,BZP`!*I"``X+C`$#BHX`!0J,
M`0ZJ;_Q"T^-Y`ZJM`0:+@4$ABT[\6]/.%0*JC``#JB$`#8N,`0**(0`."VX`
M!`J,`0ZJ3OQ"T\)Y`JJ%026+[3M9J2_\0M.L`0:++?Q;TZT5`:JE``R+;``"
MJJ4`#0N,`0&*30`#"HP!#:KA>0&JS@$&BX1!)(NM_%O33``!JJT5!:J$``Z+
MA``-"XP!!8HM``(*KOQ"TXP!#:J-_%O3@T$CB\QY!:KO.UJIK14$JB4`#*JE
M``2*[P$&B\X!!HMC``^+C_Q"TV,`#0N-`0$*I0`-JN1Y!*JB0"*+;?Q;TZT5
M`ZJ%`02J0@`.BZ4``XI"``T+C0`,"J4`#:IM_$+3H4`ABZ5Y`ZKO-UNI3OQ;
MT\X5`JJ#``6J8P`"BN\!!HNM`0:+(0`/BZ\`!`HA``X+8P`/JD[\0M-L0"R+
MPGD"JB/\6].,`0V+8Q0!JJT``JHO_$+3@P$#"ZP!`8KA>0&J30`%"NX_7*F,
M`0VJA$$DBVW\6].M%0.JS`$&BRX``@J$``R+3``!JH0`#0N,`0.*C`$.JFW\
M0M.M>0.J[P$&BX5!)8N._%O3[.M`^:,`#XO.%02J)0`-JF,`#@NE``2*K@$!
M"H_\0M.E``ZJ;OQ;TZ)`(HN%`0:+Y'D$JLX5`ZI"``6+I0$$JD(`#@MN_$+3
MI0`#BL-Y`ZKLNUVICP`-"J4`#ZI/_$+3I4`ABT'\6],A%`*JC`$&BZ4`#(N,
M``.JI0`!"XP!`HIA``0*XGD"JHP!`:I0``,*@4$MB\T!!HNL_%O3(0`-B^_W
M0/EM``*JC!4%JJT!!8J.`0$+K0$0JJ1!)(NP_$+3[0$&B\;]6]/O^T#YA``-
MB\84#JH->@6JT0`$"RQ`+(M!``W*Q3J8TB$`#$I%3+GR(4`CB^P!!8O0_4+3
M(_Y;T^__0/D.>@ZJ8Q01JB$`#(ML``$+AD`FBZ0!#LHC0".+A``&2N8!!8N"
M0"*++_Y"TX3]6]/Q>1&J0@`&BX04#*KF`T'YD@`""\$!$<I$0"2+(P`#2L$`
M!8MF0"V+C?U"TT/^6].P>0RJQ@`!BV,4$JKA!T'Y;P`&"R("$,I,_D+30@`$
M2B0`!8M"0"Z+X?U;TXUY$JI$``2+X@M!^2$4#ZHN``0+PT`CBP8"#<KL_4+3
MPP`#2D8`!8MC0#&+POU;TX]Y#ZIC``:+Y@]!^4(4#JI1``,+@4`ABZ0!#\IB
M0"*+@0`!2L0`!8LL0#"+T/U"TR'^6],.>@ZJYA-!^80!!(LA%!&JXP$.RC``
M!`MB``)*+/Y"T\,`!8M&0"V+`OY;TXQY$:K#``.+YA=!^4(4$*I-``,+@4`A
MB\0!#,H1_D+3@0`!2L8`!8LD0"^+H?U;T^\;0?F$``:+(10-JB9Z$*IB0"*+
M,``$"X,!!LKO`06+8@`"2K']0M-#0"Z+`OY;T^X?0?DM>@VJ8P`/BT(4$*I/
M``,+@4`AB\0`#<IB0"*+@0`!2L0!!8LL0"R+#OY"T^']6]/0>1"JA`$$BR$4
M#ZKL(T'Y,0`$"Z,!$,J!0"&+8@`"2H,!!8M&0":+[/U"TR+^6]./>0^JPP`#
MBT(4$:KF)T'Y3@`#"P0"#\IB0"*+@0`!2L8`!8LD0"V++?Y"T\']6].$``:+
M["M!^:9Y$:HA%`ZJXP$&RBT`!`MB``)*C`$%BT-`,(O0_4+3HOU;TPYZ#JIC
M``R+["]!^4(4#:I1``,+@4`AB\0`#LIB0"*+@0`!2H0!!8LL0"^+K_U"TR'^
M6]/M>0VJA`$$BR$4$:KL,T'Y,``$"\,!#<HO_D+38@`"2HP!!8M"0":+`_Y;
MTT8`#(MC%!"JXC=!^>QY$:J!0"&+;P`&"Z0!#,K#0".+A``!2D$`!8N$0"Z+
MXOU;TP[^0M.$``&+\3M!^<%Y$*I"%`^JA@$!RDX`!`O#``-*,`(%BV9`+8OQ
M_4+3P_U;T^T_0?EC%`ZJ+WH/JL8`$(MP``8+@D`BBR0`#\K&0".+A``"2J(!
M!8N,0"R+S?U"TP3^6].,`0*+XD-!^804$*JN>0ZJ@P`,"^T!#LKG0"^+K0$&
M2D8`!8NA02&+8OQ;TT(4`ZHA``:+[4=!^2$``@L"_D+3AD$DBT)X$*HD_%O3
MS`$"RH04`:J,`09*I@$%BV7\0M.$``R+HW@#JL8`!XLA``H+A``&"\4!"PM"
M``D+8P`("P0$`*G$``#P`P@!J040`/G@3T'Y@>1&^0```>L!`(#2@0``5/U[
M0*G_@PJ1P`-?UL[S_Y<?(`/5_7N_J0`0@-+]`P"1T?/_EQ\8`/DB``"0(0``
MD!]X`+E!1,,](@``D")`PSU`2,,]`@0`K0`(@#W]>\&HP`-?UOU[O*E"?$"3
M_0,`D?-3`:D4X`"1\P,!JO5;`JGU`P"J]@,"JO=C`ZD%C$*I`'A`N:0,`@N_
M``3K8Y2#FF)T0HNDB@*IH`,`-=_^`'&M!0!4U@(!4=A^!E,7!P`1]VIZTW<"
M%XL?(`/58`9`K>`#%:J`!@"M8`9!K7,"`9&`!@&MI/O_EW\"%^L!__]4UAH8
M2^$#%ZK@`Q2JPGY`DS'S_Y>V>@"Y\U-!J?5;0JGW8T.I_7O$J,`#7]87"(!2
M]P(`2_\"%FN`PB"+]]*6&OA^0)/B`QBJ(_/_EZ!Z0+G@`@`+H'H`N1\``7'A
M_?]4U@(72W,"&(O@`Q6JAOO_E]/__Q?W`Q.JX___%Q\@`]4?(`/5_7N\J>(/
M@!+]`P"1\U,!J?0#`*KS`P&J]5L"J3;@`)'H&P#]-11`^2@80/V@(@-3`00`
M$<+*(#C`PB&+/^``<4T+`%0""(!20@`!2P$`@%)"?$"3M_/_E^`#$ZII^_^7
M?S8`^0`$`$_``@"MP`J`/04%<'\`!6A_!`5X?Z$"9Y[@`Q.J(P1H?R($<'^@
M!`-N(01X?X`$!6X`!0=N8`0);D`$"VX@!`UNH!X/3F`Z`/U4^_^780)`^>`#
M$ZHA_%C3@0(`.6$"0/DA_%#3@08`.6$"0/DA_$C3@0H`.6$"0/F!#@`Y809`
M^2'\6-.!$@`Y809`^2'\4-.!%@`Y809`^2'\2-.!&@`Y809`^8$>`#EA"D#Y
M(?Q8TX$B`#EA"D#Y(?Q0TX$F`#EA"D#Y(?Q(TX$J`#EA"D#Y@2X`.6$.0/DA
M_%C3@3(`.6$.0/DA_%#3@38`.6$.0/DA_$C3@3H`.6$.0/F!/@`Y81)`^2'\
M6-.!0@`Y81)`^2'\4-.!1@`Y81)`^2'\2-.!2@`Y81)`^8%.`#GS4T&I]5M"
MJ>@;0/W]>\2H0_/_%P('@%)"``%+`0"`4D)\0)->\_^7K?__%^,``)!C]$#Y
M]O+_%Q\@`]7]>[^I_0,`D?U[P:C``U_6`0`"```````E<R\E<P```"]P<F]C
M+W-E;&8O97AE``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(``````$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`````&5X90``````+W!R;V,O)6DO)7,`````
M`"X`````````4$%27U1%35```````````%!!4E]04D]'3D%-10`````Z````
M`````"\`````````)7,E<R5S``!015),-4Q)0@``````````4$523$Q)0@!0
M15),-4]05```````````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140``````%!!4E]#3$5!3@````````!005)?1$5"54<`````````4$%2
M7T-!0TA%`````````%!!4E]'3$]"04Q?1$5"54<``````````%!!4E]'3$]"
M04Q?5$U01$E2`````````%!!4E]435!$25(```````!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@``````````,0````````!,1%],24)205)9
M7U!!5$@`4UE35$5-```E,#)X`````'!A<BT`````)7,E<R5S)7,`````````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@
M)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R
M(&]P97)A=&EO;BD*````````4$%42`````!P87)L`````"YP87(`````)7,E
M<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S
M```````````8`````````'!E<FP`````,`````````!005(Z.E!A8VME<CHZ
M5D524TE/3@`````Q+C`U-P```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER
M96-T;W)Y```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```````````M90``
M`````"TM````````55-%4@````!54T523D%-10``````````5$U01$E2``!4
M14U01$E2`%1%35``````5$U0```````O=&UP`````&5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN
M:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"10
M05)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE
M*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O
M9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A8VAE7VYA;65?<VEZ
M92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I
M;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@
M/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D
M<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@
M("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*
M=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O<RP@,#L*<F5A9"`D
M9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"1005)?34%'24,I.PII
M9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'24,I*2`^/2`P*2![
M"G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR
M971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL
M92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,14%.?2D@
M>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL
M97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U
M8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["G)M
M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F)B`D7D\@;F4@)TU3
M5VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@
M/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N86UE.CID:7)N86UE
M*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*
M;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R:6YT("1T;7`@/#PB
M+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D
M<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A
M:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N
M86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM
M>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E
M;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T
M;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]"GT@?0I"14=)3B![
M"DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE9"`F26YT97)N86QS
M.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV*"D["FUY("1Q=6EE
M="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H"G!A=&A?<V5P("`@
M(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@
M("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G
M(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_
M("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["F]U=',H<7%;7"1P
M<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R7W1E;7`H*3L*;W5T
M<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB72D["FUY
M("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*3L*34%'24,Z
M('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E
M;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E
M860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H
M97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@
M)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC
M7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA9VEC('-T<FEN9R`B
M)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#
M.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?
M<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I
M>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE
M;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#04-(12(@)B8@)&)U
M9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD
M(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M87)K97(@(B1B=68B
M(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T
M7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O9F9S971?<VEZ93L*
M;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO=71S*")/9F9S970@
M9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD
M<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@["FUY("5R97%U:7)E
M7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@("`@("`@("`@("`@
M("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q
M(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L
M('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S
M*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN72D["FUY("1C<F,@
M/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@
M=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN
M*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(
M+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@
M86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE
M;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L(#`W-34I.PHD4$%2
M.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B10
M05(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F=6QL;F%M93L*
M?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD(&1E9FEN
M960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S
M*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U=',H(E-(3$E".B`D
M9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C:&5[)&9U;&QN86UE
M?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL
M;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]*RL["GT*<F5A9"!?
M1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L
M("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO
M9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO9'5L97T["G)E='5R
M;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]
M.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@(D-A
M;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB:6YM;V1E*"D["B1F
M:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K*#`L(#`I.PIR971U
M<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&EN
M9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN9F\M/GMF:6QE?2`]
M("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L("1F:6QE;F%M92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@)"%=.PIR971U<FX@
M)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z(&-A;B=T(&9I;F0@
M;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97([
M"G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M
M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D
M24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF
M("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M
M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@
M+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES
M='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)4%]-04=)0RD@>PIO
M=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E8W1I;VX@:6X@9FEL
M92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@<W1A<G0@;V8@>FEP
M"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D
M8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A
M;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0II9B`H
M(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F
M)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A
M<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?
M<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@
M97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D55
M4T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H
M879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;
M,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@
M*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H
M)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!
M)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/
M)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE
M(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A
M;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I
M9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@
M<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T["GT*96QS:68@*"0Q
M(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*
M:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=0
M05)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB
M4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)
M3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/
M.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D>FEP.PII9B`H
M9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D<&%R(&]R
M(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R(CH@)"%=.PIB;&5S
M<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!A<BD@/3T@07)C
M:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@
M>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P87(@/2!D;R!["FEF
M("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM
M;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<
M4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT[
M"FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L("<\.G)A=R<L("1P
M87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@(B1P87(B.B`D(5T[
M"FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@<7%;(B1P87(B(&ES
M(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D4$M:25!?34%'24,[
M"F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z
M.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&
M:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@
M;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T(CH@)"%=.PHD9F@M
M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L;V%D97(["FEF("AD
M969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*<F5A9"!?1D@L("1L
M;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@96QS92!["FQO8V%L
M("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II9B`H(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A?%Q`<F5M*2\I('L*
M<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!4CHZ1FEL=&5R.CI0
M;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD9F@M/G!R:6YT*"1L
M;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO861E<B!T;R`B)&]U
M="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI0
M05(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E
M<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]
M"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I
M9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L('-\+R1\?"!F;W)E
M86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O<B!`1'EN84QO
M861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#.PIM>2`D;&EB
M7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@("`@("`@("`C(%A8
M6"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X["F9O<F5A8V@@;7D@
M)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I;&4L("1N86UE*3L*
M:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)&9C*3L*?0IE;'-E
M('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D:V5Y(#U^(&U\7EQ1
M)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@)#$I
M.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O6UXO72LO*"XJ*21\
M*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@*"UF("(D9&ER+R0Q
M(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*
M?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE.PIN97AT(&EF("1W
M<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL
M92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R:6YT9BAQ<5M086-K
M:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F:6QE+3Y[;F%M97T@
M.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O
M;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO8V%L("0O(#T@=6YD
M968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O<B!D:64@<7%;0V%N
M)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@/"1T:#X["F-L;W-E
M("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L>2A<)&-O;G1E;G0L
M("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A
M;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ
M4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N
M86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G3B<L(&QE;F=T:"@D
M;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ
M8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@<7%;17)R;W(@=W)I
M=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=.PIO=71S*'%Q6U=R
M:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I('L*)'II<"T^=W)I
M=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+"F]R
M(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F("(D;W5T(ET["GT*
M:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN="@B7#!#3$5!3B(I
M.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA;64I('L*;7D@)&-T
M>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H+"`P+"`P.PHD8W1X
M+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD8V%C:&5?;F%M92`]
M("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C
M:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A8VAE7VYA;64@+CT@
M(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H("1C86-H95]N86UE
M*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#2$4B*3L*?0IM>2`D
M;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I.PHD9F@M/G!R
M:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)0RD["B1F:"T^8VQO
M<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE<B!O9B`B)&]U="(Z
M("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S
M(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E
M(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I
M<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@("`@("`@("`@("`@
M(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/.CI(86YD;&4*)&9H
M+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE('%Q6V9D;W!E;B@I
M(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@M<R!?
M1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["B@D>FEP+3YR96%D
M1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI
M=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V
M-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,
M:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B17AT<F%C=&EN9R!Z
M:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U
M;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H
M("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O
M<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT
M('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N
M9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D
M,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM0
M05)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F
M)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S
M*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@
M97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X
M=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B+BXN72D[
M"B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D@/3T@
M07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;17)R;W(@97AT<F%C
M=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y
M<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R;F%M92D["FUK9&ER
M("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII9B`H)$5.5GM005)?
M0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["GT*96QS92!["F]P
M96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@
M9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K("1F:"P@)&UA9VEC
M7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL
M(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B
M*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?
M<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM
M("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D8G5F+"`D8V%C:&5?
M;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H95]D:7(@/2`B8V%C
M:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D8V%C:&5?9&ER*2![
M"B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%27T-,14%.?2`](#$[
M"GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H95]D:7(B.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*
M;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY
M("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE
M(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2![
M"FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N
M("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I;G0@)&9H("1C;VYT
M96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@
M(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D
M969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R
M('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B
M(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-
M17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N
M86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%
M35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P
M*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!2
M3T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@
M,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R
M;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D<WES>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0
M051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I
M<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]
M7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA
M;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U]
M)'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]
M("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345].PII9B`H:6YD97@H
M)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B
M+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D
M("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97
M:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO
M;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L
M:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[
M4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*
M)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$
M(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@*2`I('L*9&5L971E
M("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,
M7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H
M)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0I]
M"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP
M<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*
M?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G
M<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C
M:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N
M9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E
M<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2
M+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E
M;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I
M<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64[
M"D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<
M*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*
M7U]%3D1?7PH``````'!E<FQX<VDN8P````````!03D```````!!+0```````
M````````````3$```````#!.0```````.$Y```````!`3D```````$A.0```
M```````````````83D```````"!.0```````````````````0T%#2$4`````
M`````````2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````
M`````````````1L#.PP!```@````T(K__WP&``#0C/__)`$``!"-__\X`0``
M,(W__U`!``!@C?__9`$``*"-__]X`0``T(W__YP!``#@C?__L`$``-".__\8
M`@``8(___T`"``#$D/__D`(``/"1___8`@```)/__R@#```0E?__?`,``("5
M__^@`P``L)7__[0#``"$EO__Y`,``)"6___X`P``P)C__U@$``#PF/__?`0`
M`%":___L!```!)___R0%``!PG___1`4``)"?__]D!0``L*#__Z`%``"4IO__
M&`8``*"H__](!@``D*G__Z@&``!`NO__S`8``("Z___L!@``D+O__R0'``!0
MO?__8`<````````0``````````%Z4@`$>!X!&PP?`!`````8````I(O__SP`
M````00<>%````"P```#0B___!```````````````$````$0```#8B___,```
M```````0````6````/2+__\\`````````"````!L````((S__S``````00X@
MG02>`T*3`DC>W=,.`````!````"0````+(S__P0`````````9````*0````H
MC/__[`````!!#D"=")X'0I,&E`5"F`&7`D66`Y4$5=;50=C70][=T]0.`$$.
M0),&E`65!)8#EP*8`9T(G@=/UM5!V-=!WMW3U`X`00Y`DP:4!9T(G@="EP*8
M`4'8UP`D````#`$``+",__^0`````$$.L`&=%IX51),450K>W=,.`$$+````
M3````#0!```8C?__9`$```!!#L`!G1B>%TB4%9,61-331][=#@!!#L`!DQ:4
M%9T8GA=!EA.5%'4*U--!UM5!"TG3U-760905DQ9!EA.5%`!$````A`$``"R.
M__\H`0```$$.4$(.T(`$0YV*0)Z)0$*3B$"4AT!#E89`EH5`0Y>$0',*W=[7
MU=;3U$$.@(`$00X`00L```!,````S`$``!"/__\,`0```$(.P"!$G8@$GH<$
M0I.&!)2%!%&5A`1/U5/=WM/4#@!!#L`@DX8$E(4$E80$G8@$GH<$0=5#"I6$
M!$$+096$!%`````<`@``T(___PP"````00Y@G0R>"T*3"I0)394(E@>7!I@%
M?`K>W=?8U=;3U`X`00M(F@.9!%P*VME!"TC9VD*9!)H#0]G:09H#F01"VMD`
M`"````!P`@``C)'__V@`````00X@G02>`T23`I0!3M[=T]0.`!````"4`@``
MV)'__RP`````````+````*@"``#TD?__U`````!"#L!`0YV(")Z'"$*3A@B4
MA0AJ"MW>T]0.`$$+````$````-@"``"8DO__!`````````!<````[`(``)"2
M__\L`@```$(.X"%#G9P$GIL$0I.:!)29!$.5F`26EP1<"MW>U=;3U`X`00M)
MF)4$EY8$19F4!'4*V-=!V4$+5@K8UT'900M$U]C909B5!)>6!$&9E`0@````
M3`,``&"4__\L`````$$.()T$G@-#DP)&WMW3#@````!L````<`,``&R4__]<
M`0```$(.P"!#G8@$GH<$1I6$!$24A023A@1EU--!U4'=W@X`00[`()6$!)V(
M!)Z'!$'52]W>#@!!#L`@DX8$E(4$E80$G8@$GH<$2PK4TT+50@M!T]35092%
M!).&!$&5A`0`-````.`#``!<E?__M`0```!!#E"="IX)1),(E`=%E0:6!9<$
MF`,#&`$*WMW7V-76T]0.`$$+```<````&`0``-B9__]L`````$$.()T$G@-6
M"M[=#@!!"QP````X!```))K__R``````00X0G0*>`4;>W0X`````.````%@$
M```DFO__&`$```!!#D"=")X'1),&E`5#E026`U<*WMW5UM/4#@!!"TL*WMW5
MUM/4#@!!"P``=````)0$```(F___Y`4```!!#I`#1ITPGB]#DRZ4+4.5+)8K
M5Y@IERI!FB>9*`)T"MC70=K90=W>U=;3U`X`00L"D]?8V=I,W=[5UM/4#@!!
M#I`#DRZ4+94LEBN7*I@IF2B:)YTPGB]ZU]C9VD&8*9<J09HGF2@`+`````P%
M``!TH/__"`(```!!#D"=")X'1),&E`5$E026`P):"M[=U=;3U`X`00L`,```
M`#P%``!0HO__Z`````!!#C"=!IX%1),$E`-A"M[=T]0.`$$+40K>W=/4#@!!
M"P```"@```!P!0``3(3__^P!````00Y0G0J>"423")0'`E0*WMW3U`X`00L`
M````(````)P%``#@HO__K!````!!#J`%1YU4GE,#(00*W=X.`$$+'````,`%
M``!LL___0`````!!#A"=`IX!3M[=#@`````T````X`4``(RS__\(`0```$$.
M0)T(G@=#DP:4!4.5!)8#0Y<"F`%C"M[=U]C5UM/4#@!!"P```#@````8!@``
M9+3__\`!````00Y`G0B>!T.3!I0%0Y4$E@-"!4@"`F`*WMW5UM/4!D@.`$$+
M`````````!````!4!@``Z+7__PP`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````&T```````-`:0``````````````````!````
M`````.8"`````````0````````#V`@````````$```````````,````````,
M```````````40```````#0````````",2D```````!D`````````N/U!````
M```;``````````@`````````&@````````#`_4$``````!P`````````"```
M``````#U_O]O`````)@"0```````!0````````!X"4````````8`````````
M``-````````*`````````#<#````````"P`````````8`````````!4`````
M```````````````#`````````.C_00```````@````````"@!0```````!0`
M````````!P`````````7`````````&`.0```````!P````````"@#4``````
M``@`````````P``````````)`````````!@`````````_O__;P````!`#4``
M`````/___V\``````@````````#P__]O`````+`,0```````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````T/U!
M````````````````````````````````````````````````````````````
M`````````````````````"`40```````(!1````````@%$```````"`40```
M````(!1````````@%$```````"`40```````(!1````````@%$```````"`4
M0```````(!1````````@%$```````"`40```````(!1````````@%$``````
M`"`40```````(!1````````@%$```````"`40```````(!1````````@%$``
M`````"`40```````(!1````````@%$```````"`40```````(!1````````@
M%$```````"`40```````(!1````````@%$```````"`40```````(!1`````
M```@%$```````"`40```````(!1````````@%$```````"`40```````(!1`
M```````@%$```````"`40```````(!1````````@%$```````"`40```````
M(!1````````@%$```````"`40```````(!1````````@%$```````"`40```
M````(!1````````@%$```````"`40```````(!1````````@%$```````"`4
M0```````(!1````````@%$```````"`40```````(!1````````@%$``````
M```````````````````````*4$%2+G!M"@``````````6$Y```````!'0T,Z
M("A-86=E:6$@,3(N,BXQ+3`N,C`R,C$Q,3DN,2YM9V$Y*2`Q,BXR+C$@,C`R
M,C$Q,3@`1T-#.B`H36%G96EA(#$R+C(N,2TP+C(P,C(Q,3(V+C$N;6=A.2D@
M,3(N,BXQ(#(P,C(Q,3(V```N<VAS=')T86(`+FEN=&5R<``N;F]T92YG;G4N
M8G5I;&0M:60`+FYO=&4N04))+71A9P`N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L82YD>6X`+G)E
M;&$N<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD
M<@`N96A?9G)A;64`+FEN:71?87)R87D`+F9I;FE?87)R87D`+F1A=&$N<F5L
M+G)O`"YD>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N
M=```````````````````````````````````````````````````````````
M```````````````````````````````+`````0````(`````````.`)`````
M```X`@```````!L````````````````````!````````````````````$P``
M``<````"`````````%0"0```````5`(````````D````````````````````
M!````````````````````"8````'`````@````````!X`D```````'@"````
M````(`````````````````````0````````````````````T````]O__;P(`
M````````F`)```````"8`@```````&@`````````!0`````````(````````
M````````````/@````L````"```````````#0`````````,```````!X!@``
M``````8````!````"``````````8`````````$8````#`````@````````!X
M"4```````'@)````````-P,```````````````````$`````````````````
M``!.````____;P(`````````L`Q```````"P#````````(H`````````!0``
M```````"``````````(`````````6P```/[__V\"`````````$`-0```````
M0`T```````!@``````````8````"````"````````````````````&H````$
M`````@````````"@#4```````*`-````````P``````````%``````````@`
M````````&`````````!T````!````$(`````````8`Y```````!@#@``````
M`*`%````````!0```!<````(`````````!@`````````?@````$````&````
M```````40````````!0````````8````````````````````!```````````
M`````````'D````!````!@`````````@%$```````"`4````````X`,`````
M`````````````!````````````````````"$`````0````8``````````!A`
M````````&````````(PR``````````````````!`````````````````````
MB@````$````&`````````(Q*0```````C$H````````4````````````````
M````!````````````````````)`````!`````@````````"@2D```````*!*
M````````D$(``````````````````!````````````````````"8`````0``
M``(`````````,(U````````PC0````````P!```````````````````$````
M````````````````I@````$````"`````````$".0```````0(X```````!H
M!@``````````````````"````````````````````+`````.`````P``````
M``"X_4$``````+C]````````"`````````````````````@`````````"```
M``````"\````#P````,`````````P/U!``````#`_0````````@`````````
M```````````(``````````@`````````R`````$````#`````````,C]00``
M````R/T````````(````````````````````"````````````````````-4`
M```&`````P````````#0_4$``````-#]````````\`$````````&````````
M``@`````````$`````````#>`````0````,`````````P/]!``````#`_P``
M`````"@````````````````````(``````````@`````````XP````$````#
M`````````.C_00``````Z/\```````#X`0``````````````````"```````
M```(`````````.P````!`````P````````#@`4(``````.`!`0``````*```
M``````````````````@```````````````````#R````"`````,`````````
M$`)"```````(`@$``````$`````````````````````0````````````````
M````]P````$````P````````````````````"`(!``````!N````````````
M`````````0`````````!``````````$````#````````````````````````
I`'8"`0````````$```````````````````$`````````````````````
